@@ -171,8 +171,7 @@ void GetConfigOperation::start()
     Q_D(GetConfigOperation);
     if (BackendManager::instance()->method() == BackendManager::InProcess) {
         auto backend = d->loadBackend();
-        d->config = backend->config();
-        KScreen::BackendManager::instance()->setConfig(d->config);
+        d->config = backend->config()->clone();
         d->loadEdid(backend);
         emitResult();
     } else {
